import { Section } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";
import {H4} from "../components/Headings";

export function Methods() {
  useTabNavigation();
    return (
      <>
        <Section title="Introduction" id="Introduction">
          ...
        </Section>
        <Section title="Patch Clamp" id="Patch Clamp">
          <H4 text="Patch Clamp: A Key Tool in Electrophysiology"></H4>
          <p>The patch clamp technique is a highly sensitive method for measuring ionic currents through individual ion channels in cells, making it a cornerstone of electrophysiological research. Initially developed by Erwin Neher and Bert Sakmann in the 1970s [1], this technique has evolved into various configurations, including the Whole-Cell and Single-Channel recordings [2], which provide critical insights into the functional properties of ion channels. </p>
          <H4 text="Principles of the patch clamp technique"></H4>
          <p>Patch clamp recording involves the use of a glass micropipette which is manufactured from a glass capillary through the use of a Micropipette Puller. The micropipette is then filled with an electrolyte solution, which is subsequently brought into contact with the cell membrane. By applying gentle suction, a high-resistance seal called giga seal is formed between the pipette tip and the membrane patch. This enables the measurement of ionic currents with minimal noise interference [3]. <strong>Whole-Cell Configuration</strong> records currents from the entire cell by rupturing the membrane patch, accessing the intracellular environment, and is useful for analysing overall ion channel activity and cellular responses. <strong>Single-Channel Recording</strong> measures currents through individual ion channels without rupturing the membrane, enabling high-resolution study of channel conductance, gating, and selectivity [2].</p>
          <figure>
            <iframe title="Bielefeld-CeBiTec: Patch Clamp Measurement (2024)" width="560" height="315" src="https://video.igem.org/videos/embed/0d948e57-5997-430a-a2df-815b71a2fc67?autoplay=1" frameBorder="0" allowFullScreen={true} sandbox="allow-same-origin allow-scripts allow-popups allow-forms"></iframe>
            <figcaption> <b>Figure 1.</b> Microscopic recording of micropipette sealing of a HEK293 cell </figcaption>
          </figure>


          <p>The success of patch clamp experiments heavily depends on the composition of the solutions used. Typically, two main types of solutions are employed: The <strong>Pipette Solution</strong> in the micropipette mimics the intracellular environments, while the <strong>Bath Solution</strong> surrounds the cell and usually contains components that replicate the extracellular environment. Both solutions are meticulously designed to reflect the physiological conditions under which the cells operate, thereby ensuring that the measurements accurately reflect ion channel activity in a natural setting [2].</p>
          <figure>
            <img src="https://static.igem.wiki/teams/5247/photos/for-wiki-texts/meth-patch-clamp/bild-meth-patch-clamp.png" alt="Patch clamp setup"/>
            <figcaption><b>Figure 2.</b> Patch clamp setup</figcaption>
          </figure>
          <H4 text="Application in CFTR gene prime editing validation"></H4>
          <p>In our ongoing research project focusing on the treatment of cystic fibrosis (CF), our patch clamp measurements, performed in collaboration with Dr. Oliver Dräger from the Cellular Neurophysiology working group at Bielefeld University, serve as a powerful validation tool for the assessment of the functional correction of the CFTR gene, particularly the common F508del mutation, via prime editing. The patch clamp technique can be employed in this context to measure the resulting chloride ion channel activity which is altered by the mutation [4]. Whole-Cell recordings were performed to assess whether the corrected CFTR channels function similarly to those in healthy cells. If the chloride ion currents in the edited cells approach levels of healthy cells, this would strongly suggest successful gene editing and validate the functionality of our therapeutic approach.</p>



        </Section>
        <Section title="Cell Culture" id="Cell Lines">
          <H4 text="HEK293 and HEK293T cell lines"></H4>
          <p>For testing our prime editing approach, we needed an easy-to-handle cell line with a measurable high expression of CFTR and the CFTR F508del mutation. When talking to Mattijs Bulcaen from the Laboratory of Molecular Virology and Gene Therapy at KU Leuven, he recommended to use HEK293T cell lines overexpressing CFTR they had used. HEK293 cells are a very common immortalized human cell line derived from the kidneys of a female embryo. They are particularly suited to research due to their convenient handling and transfection properties. Basic HEK293 cells were provided to us by the Cellular and Molecular Biotechnology working group at Bielefeld University led by Prof. Dr. Kristian Müller, who is also one of the Principal Investigators of our team. HEK293T cells express an additional tsA1609 allele of the SV40 large T-antigen, allowing for replication of vectors containing the SV40 origin of replication.[2] Besides the native CFTR gene, which is not expressed in HEK cells, the HEK293T cell lines used in Leuven carry another copy of the gene embedded in an expression cassette. The cassette includes a CMV promoter, which is a standard promoter used for gene overexpression in human cells derived from the human Cytomegalovirus[4], as well as a puromycin resistance co-expressed with the CFTR allowing for continuous selection of CFTR expressing cells. The whole construct was stably inserted into the genome using lentiviral transduction.1,3 </p>
          <figure>
            <img src="https://static.igem.wiki/teams/5247/photos/for-wiki-texts/meth-used-cells/mikroskopie-hek293t.png" alt="Phase contrast image of HEK293T at 20x magnification"/>
            <figcaption> <b>Figure 3.</b>Phase contrast image of HEK293T at 20x magnification</figcaption>
          </figure>
          <H4 text="CFBE41o- cell line "></H4>
          <p>The CFBE41o- cell line, derived from bronchial epithelial cells of a one-year-old cystic fibrosis patient, serves as a vital model for studying cystic fibrosis. These cells closely mimic the physiological environment of the airway epithelium, allowing for more accurate studies on how CFTR mutations affect cell function and response to treatments. They were immortalized through calcium-phosphate-mediated transfection using a replication-defective pSVori plasmid that carries the simian virus 40 large T-antigen (SV40-LT). The plasmid's defective origin of replication prevents viral propagation, thus preserving essential physiological characteristics of the cells while enabling them to develop differentiated morphologies. CFBE41o- cells are homozygous for the ΔF508-CFTR mutation [1]. We are happy we got this cell line with permission from Prof. Dr. Zoya Ignatova, who is leader of a working group at the Institute for Biochemistry and Molecular Biology of Hamburg University and an iGEM supporter since a long time [6]. </p>
          <H4 text="Human nasal epithelial cells (hNECs)"></H4>
          <p>Human nasal epithelial cells were obtained by nasal brushing, a minimally invasive method. These cells function/act as primary cultures. Cultivated in air-liquid interface (ALI) cultures and apical-out airway organoids (AOAO), they serve as a suitable model to visualise the functional epithelium of the airways in a differentiated form. The in vivo aspects of an airway disease, such as CF, can be modelled using donors with those airway diseases (5) This model is therefore particularly suitable for testing our prime editing complex. </p>

        </Section>
      </>
    );
  }
  